// @flow
'use strict'

const joi = require('joi')

const server = require('../server')
const handler = require('./result-processor-handler')
const { requireRole } = require('../lib/role')
const { ROLES, TASK_STAGE } = require('../constant')

const BASE_PATH = '/admin/result-processor'

/**
 * Re-run result processor
 */
server.post({
  path: `${BASE_PATH}`,
  validation: {
    schema: joi.object().keys({
      query: joi.object().keys({
        studyId: joi.string().guid(),
        taskId: joi.string().guid(),
        stage: joi.string().valid(Object.values(TASK_STAGE))
      }).or('studyId', 'taskId').required()
    })
  }
}, [
  requireRole([
    ROLES.SYSTEM_ADMIN
  ]),
  handler.rerunResultProcessor
])
