// @flow
'use strict'

const joi = require('joi')

const referenceFileSchema = joi.string().uri({
  scheme: ['s3']
})
const idSchema = joi.string().required()
const uuidSchema = joi.string().guid().required()

module.exports = joi.object().keys({
  subtaskOutputData: joi.object().keys({
    studyId: uuidSchema,
    taskId: uuidSchema,
    dicom: joi.any(),
    series_extraction_qc: joi.any(),
    series_ranking: joi.any(),
    central_line_detection: joi.any(),
    cmpr: joi.any(),
    attraction_points: joi.any(),
    variable_analysis: joi.any(),
    refinement: joi.boolean(),
    errors: joi.array().items(
      joi.object().keys({
        code: joi.string().required(),
        message: joi.string().required(),
        task: joi.string().required(),
        order: joi
          .number()
          .integer()
          .required()
      })
    )
  }).required(),

  subtaskResult: joi.object().keys({
    studyId: uuidSchema,
    taskId: uuidSchema,
    status: joi.number().integer().required(),
    series: joi.array().items(
      joi.object().keys({
        id: idSchema,
        name: joi.string(),
        ranking: joi.number(),
        metadata: joi.object(),
        imageCount: joi.number().integer(),
        seriesExtractionRefFile: referenceFileSchema,
        resampledSeriesExtractionRefFile: referenceFileSchema,
        centralLineRefFile: referenceFileSchema,
        aortaMesh: referenceFileSchema,
        axialThumbnail: joi.object().keys({
          width: joi.number().integer(),
          height: joi.number().integer(),
          imageCount: joi.number().integer(),
          prefix: referenceFileSchema
        }),
        frames: joi.object().keys({
          metadata: joi.object().keys({
            frameType: joi.string(),
            bitDepth: joi.number().integer(),
            bytePerPixel: joi.number().integer(),
            pixelSpacing: joi.number()
          }),
          axial: joi.object().keys({
            width: joi.number().integer(),
            height: joi.number().integer(),
            imageCount: joi.number().integer(),
            prefix: referenceFileSchema
          }),
          coronal: joi.object().keys({
            width: joi.number().integer(),
            height: joi.number().integer(),
            imageCount: joi.number().integer(),
            prefix: referenceFileSchema
          }),
          sagittal: joi.object().keys({
            width: joi.number().integer(),
            height: joi.number().integer(),
            imageCount: joi.number().integer(),
            prefix: referenceFileSchema
          })
        }),
        vessels: joi.array().items(
          joi.object().keys({
            id: idSchema,
            smpr: joi.object().keys({
              width: joi.number().integer(),
              height: joi.number().integer(),
              length: joi.number().integer(),
              referenceFile: referenceFileSchema
            }),
            windowLevel: joi.number().integer(),
            windowWidth: joi.number().integer(),
            transformMatrix: referenceFileSchema,
            segments: joi.array().items(
              joi.object().keys({
                start: joi.number().integer(),
                end: joi.number().integer(),
                id: idSchema,
                label: joi.string()
              })
            ),
            label: joi.string(),
            start: joi.number().integer(),
            end: joi.number().integer(),
            vesselWallRefFile: referenceFileSchema,
            lumenWallRefFile: referenceFileSchema,
            variablesRefFile: referenceFileSchema,
            vesselWallMesh: referenceFileSchema
          }).unknown(true)
        )
      }).unknown(true)
    )
  }).required()
})
