// @flow
'use strict'

const joi = require('joi')

const server = require('../server')
const handler = require('./series-handler')
const { ROLES, LAB_BASE_PATH } = require('../constant')
const { requireRole } = require('../lib/role')

const STUDY_PATH = '/cases'
const SERIES_PATH = '/series'

/**
 * Get series by id
 */
server.get({
  path: `${LAB_BASE_PATH}${STUDY_PATH}/:studyId${SERIES_PATH}/:seriesId`,
  validation: {
    schema: joi.object().keys({
      params: joi.object().keys({
        studyId: joi.string().guid().required(),
        seriesId: joi.string().min(1).required()
      }).required()
    })
  }
}, [
  requireRole([
    ROLES.SYSTEM_ADMIN,
    ROLES.LAB_ADMIN,
    ROLES.LAB_USER
  ]),
  handler.getSeriesById
])

/**
 * Get series for dicom viewer
 */
server.get({
  path: `${LAB_BASE_PATH}${STUDY_PATH}/:studyId${SERIES_PATH}/:seriesId/viewer`,
  validation: {
    schema: joi.object().keys({
      params: joi.object().keys({
        studyId: joi.string().guid().required(),
        seriesId: joi.string().min(1).required()
      }).required()
    })
  }
}, [
  requireRole([
    ROLES.SYSTEM_ADMIN,
    ROLES.LAB_ADMIN,
    ROLES.LAB_USER
  ]),
  handler.getSeriesViewer
])

/**
 * Analyze a series
 */
server.post({
  path: `${LAB_BASE_PATH}${STUDY_PATH}/:studyId${SERIES_PATH}/:seriesId/analyze`
}, [
  requireRole([
    ROLES.SYSTEM_ADMIN,
    ROLES.LAB_ADMIN,
    ROLES.LAB_USER
  ]),
  handler.analyzeSeries
])
