// @flow
'use strict'

const db = require('../lib/db')
const {
  tableName: studyTable,
  tableColumn: studyColumn
} = require('@cleerly/coronary-db-schema/study')
const {
  tableName: reviewTable,
  tableColumn: reviewColumn
} = require('@cleerly/coronary-db-schema/study-review')

module.exports = {
  async getSeriesById (studyId: string, seriesId: string) {
    const result = await db
      .first(db.raw(`${reviewColumn.series} -> '${seriesId}' as series_item`))
      .from(reviewTable)
      .where(reviewColumn.studyId, studyId)
      .orderBy(reviewColumn.dateCreated, 'desc')

    if (!result) {
      return null
    }
    return result.seriesItem
  },

  async getSeriesByIdForUpdate (studyReviewId: string, seriesId: string, trx: Function) {
    return db
      .transacting(trx)
      .first(db.raw(`${reviewTable}.${reviewColumn.id},
        ${reviewTable}.${reviewColumn.series} -> '${seriesId}' as series,
        ${reviewTable}.${reviewColumn.reviewerId},
        ${studyTable}.${studyColumn.status}`))
      .from(reviewTable)
      .innerJoin(studyTable, `${reviewTable}.${reviewColumn.studyId}`, `${studyTable}.${studyColumn.id}`)
      .where(`${reviewTable}.${reviewColumn.id}`, studyReviewId)
      .andWhere(studyColumn.deleted, false)
  },

  /**
   * Update series
   *
   * @param studyReviewId
   * @param seriesId
   * @param newSeries is a full series object
   * @param trx
   * @returns {Promise<*>}
   */
  async updateSeries (studyReviewId: string, seriesId: string, newSeries: Object, trx: Function) {
    return db(reviewTable)
      .transacting(trx)
      .where(reviewColumn.id, studyReviewId)
      .update({
        series: db.raw(`jsonb_set(${reviewColumn.series}, '{"${seriesId}"}', '${JSON.stringify(newSeries)}')`),
        date_updated: db.fn.now()
      })
  }
}
