// @flow
'use strict'

import type { PersistedSeries, Series } from '../types'

const _ = require('lodash')
const { url } = require('config')
const utils = require('../utils')
const { getVesselSummary, vesselComparator } = require('../vessel/vessel-util')

module.exports = {
  getSeries (series: Object): Series {
    const s = {
      id: series.id,
      name: series.name,
      imageCount: 0,
      thumbnails: [],
      metadata: series.metadata,
      pending: series.pending,
      notAnalyzed: series.notAnalyzed,
      vessels: _(series.vessels)
        .map(v => getVesselSummary(v))
        .sort(vesselComparator)
        .value()
    }

    if (series.axialThumbnail) {
      const prefix = `${url.content}/${utils.getS3InfoFromURI(series.axialThumbnail.prefix).key}`
      const extension = series.axialThumbnail.frameType || 'jpeg'
      s.thumbnails = _.range(series.axialThumbnail.imageCount).map(index => `${prefix}${index}.${extension}`)
      s.imageCount = series.axialThumbnail.imageCount
    }

    return _.omitBy(s, _.isNil)
  },

  toObject (seriesList: Array<Series>): { [string]: PersistedSeries } {
    const s = _.map(seriesList, function (series) {
      const srs = _.cloneDeep(series)
      srs.vessels = _.keyBy(srs.vessels, 'id')
      return srs
    })
    return _.keyBy(s, 'id')
  },

  toArray (seriesMap: { [string]: PersistedSeries }): Array<Series> {
    const s = _.map(seriesMap, function (series) {
      const srs = _.cloneDeep(series)
      srs.vessels = _.values(srs.vessels, 'id')
      return srs
    })
    return _.orderBy(_.values(s, 'id'), 'ranking', 'desc')
  }
}
