// @flow
'use strict'

import type { Point3D } from '../types'

const https = require('https')
const axios = require('axios')
const config = require('config')
const { CENTRAL_LINE_SPACING } = require('./vessel-constant')
const { requestTimeout } = require('../constant')

const helperServicesUrl: string = config.get('services.helperServicesUrl')

const axiosInstance = axios.create({
  baseURL: `${helperServicesUrl}/api/v1`,
  timeout: requestTimeout,
  httpsAgent: new https.Agent({ keepAlive: true })
})

module.exports = {
  axiosInstance,

  async manualHelper (seriesFile: string, unknownPath: Array<Point3D>, pixelSpacing: Array<number>) {
    const resp = await axiosInstance.post('/manual-helper/', {
      seriesFile,
      pixelSpacing,
      vertexes: unknownPath
    })

    return resp.data
  },

  async preloadCentralPoint (
    seriesExtractionRefFile: string,
    transformMatrixRefFile: string,
    centralLineSpacing: number = CENTRAL_LINE_SPACING) {
    return axiosInstance.post('/central-point-preload/', {
      seriesExtractionRefFile,
      transformMatrixRefFile,
      centralLineSpacing
    })
  },

  async adjustCentralPoint (
    centralPoints: Array<Point3D>,
    seriesExtractionRefFile: string,
    transformMatrixRefFile: string,
    centralLineSpacing: number = CENTRAL_LINE_SPACING) {
    return axiosInstance.put('/central-point/',
      {
        centralPoints,
        seriesExtractionRefFile,
        transformMatrixRefFile,
        centralLineSpacing
      },
      {
        responseType: 'stream'
      }
    )
  }
}
