// @flow
'use strict'

const _ = require('lodash')

const LABEL_MAP = {
  RCA: {
    isVessel: true,
    labelShort: 'RCA',
    labelLong: 'Right Coronary Artery'
  },
  PRCA: {
    isSegment: true,
    labelShort: 'pRCA',
    labelLong: 'Proximal Right Coronary Artery'
  },
  MRCA: {
    isSegment: true,
    labelShort: 'mRCA',
    labelLong: 'Mid Right Coronary Artery'
  },
  DRCA: {
    isSegment: true,
    labelShort: 'dRCA',
    labelLong: 'Distal Right Coronary Artery'
  },
  RPDA: {
    isVessel: true,
    isSegment: true,
    labelShort: 'R-PDA',
    labelLong: 'Right Posterior Descending Artery'
  },
  LM: {
    isVessel: true,
    isSegment: true,
    labelShort: 'LM',
    labelLong: 'Left Main'
  },
  LAD: {
    isVessel: true,
    labelShort: 'LAD',
    labelLong: 'Left Anterior Descending'
  },
  PLAD: {
    isSegment: true,
    labelShort: 'pLAD',
    labelLong: 'Proximal Left Anterior Descending'
  },
  MLAD: {
    isSegment: true,
    labelShort: 'mLAD',
    labelLong: 'Mid Left Anterior Descending'
  },
  DLAD: {
    isSegment: true,
    labelShort: 'dLAD',
    labelLong: 'Distal Left Anterior Descending'
  },

  D1: {
    isVessel: true,
    isSegment: true,
    labelShort: 'D1',
    labelLong: 'First Diagonal Branch'
  },
  D2: {
    isVessel: true,
    isSegment: true,
    labelShort: 'D2',
    labelLong: 'Second Diagonal Branch'
  },

  CX: {
    isVessel: true,
    labelShort: 'Cx',
    labelLong: 'Circumflex'
  },
  PCX: {
    isSegment: true,
    labelShort: 'pCx',
    labelLong: 'Proximal Circumflex'
  },
  DLCX: {
    isSegment: true,
    labelShort: 'dLCx',
    labelLong: 'Distal Left Circumflex'
  },

  OM1: {
    isVessel: true,
    isSegment: true,
    labelShort: 'OM1',
    labelLong: 'First Obtuse Marginal'
  },
  OM2: {
    isVessel: true,
    isSegment: true,
    labelShort: 'OM2',
    labelLong: 'Second Obtuse Marginal'
  },

  LPDA: {
    isVessel: true,
    isSegment: true,
    labelShort: 'L-PDA',
    labelLong: 'Left Posterior Descending Artery'
  },
  RPLB: {
    isVessel: true,
    isSegment: true,
    labelShort: 'R-PLB',
    labelLong: 'Right Posterior Lateral Branch'
  },
  LPLB: {
    isVessel: true,
    isSegment: true,
    labelShort: 'L-PLB',
    labelLong: 'Left Posterior Lateral Branch'
  },
  RI: {
    isVessel: true,
    isSegment: true,
    labelShort: 'RI',
    labelLong: 'Ramus Intermedius'
  }
}

function getLabelKey (label: string): string {
  if (!_.isString(label)) {
    return ''
  }
  return label.replace(/[^0-9a-zA-Z]/g, '').toUpperCase()
}

module.exports = {
  getLabelKey,

  /**
   * Check if the label is unknown
   * @param label
   * @returns {boolean}
   */
  isUnknownLabel (label: string): boolean {
    if (!label) {
      return true
    }

    const labels = label.split(/\W/)
    for (let l of labels) {
      if (!LABEL_MAP.hasOwnProperty(getLabelKey(l))) {
        return true
      }
    }
    return false
  }
}
