// @flow
'use strict'

import type { Vessel } from '../types'

const db = require('../lib/db')
const {
  tableName: reviewTable,
  tableColumn: reviewColumn
} = require('@cleerly/coronary-db-schema/study-review')

module.exports = {
  async getVesselById (studyReviewId: string, seriesId: string, vesselId: string, trx?: Function) {
    const sql = db(reviewTable)
    if (trx) {
      sql.transacting(trx)
    }
    return sql
      .first(db.raw(`
        ${reviewColumn.series} #> '{"${seriesId}", vessels, "${vesselId}"}' as vessel,
        ${reviewColumn.reviewerId},
        ${reviewColumn.series} #> '{"${seriesId}", frames, metadata, pixelSpacing}' as pixel_spacing`))
      .where(reviewColumn.id, studyReviewId)
  },

  async getVesselByIdForUpdate (studyReviewId: string, seriesId: string, vesselId: string, trx: Function) {
    return db(reviewTable)
      .transacting(trx)
      .first(db.raw(`${reviewColumn.series} #> '{"${seriesId}", vessels, "${vesselId}"}' as vessel,
        ${reviewColumn.reviewerId},
        ${reviewColumn.series} #> '{"${seriesId}", frames, metadata, pixelSpacing}' as pixel_spacing`))
      .where(reviewColumn.id, studyReviewId)
  },

  async updateVessel (studyReviewId: string, seriesId: string, vesselId: string, newVessel: Vessel, trx: ?Function) {
    const dbTrx = trx || db
    return dbTrx(reviewTable)
      .where(reviewColumn.id, studyReviewId)
      .update({
        series: db.raw(`jsonb_set(${reviewColumn.series}, '{"${seriesId}", vessels, "${vesselId}"}', '${JSON.stringify(newVessel)}')`),
        date_updated: db.fn.now()
      })
      .returning(reviewColumn.dateUpdated)
  }
}
