// @flow
'use strict'

import type { Vessel } from '../types'
import type { Area } from './vessel-type'

const _ = require('lodash')
const url = require('config').get('url')
const { getLabelKey } = require('./vessel-label-util')
const { getS3InfoFromURI } = require('../utils')
const { TOOLS } = require('./vessel-constant')

const VESSEL_ORDER = {
  RCA: 1,
  RPDA: 2,
  RPLB: 3,
  LMLAD: 4,
  D1: 5,
  D2: 6,
  D3: 7,
  D4: 8,
  CX: 9,
  OM1: 10,
  OM2: 11,
  LPLB: 12,
  LPDA: 13,
  RI: 14
}

function switchMeshFormatToDrc (vesselWallMesh: ?string) {
  if (vesselWallMesh) {
    const originalUrl = `${url.content}/${getS3InfoFromURI(vesselWallMesh).key}`
    return originalUrl.substr(0, originalUrl.lastIndexOf('.')) + '.drc'
  }
}

function getVesselSummary (vessel: Object) {
  return _.omitBy({
    id: vessel.id,
    label: vessel.label,
    start: vessel.start,
    end: vessel.end,
    segments: vessel.segments,
    vertexes: vessel.vertexes,
    notAnalyzed: vessel.notAnalyzed,
    isBestCombination: vessel.isBestCombination,
    // TODO: hardcoded reAnalysisRequested here. It should be set when the physician send back the study
    // reAnalysisRequested: (vessel.id === 'v2' || vessel.id === 'v5'),
    pending: vessel.pending,
    reviewed: vessel.reviewed,
    vesselWallMesh: switchMeshFormatToDrc(vessel.vesselWallMesh)
  }, _.isNil)
}

module.exports = {
  switchMeshFormatToDrc,
  vesselComparator (v1: Vessel, v2: Vessel): number {
    return VESSEL_ORDER[getLabelKey(v1.label)] - VESSEL_ORDER[getLabelKey(v2.label)]
  },

  getVesselSummary,

  getVesselDetails (vessel: Object, pixelSpacing: number): Vessel {
    return _.omit({
      ...getVesselSummary(vessel),
      areas: vessel.areas,
      windowWidth: vessel.windowWidth,
      windowLevel: vessel.windowLevel,
      pixelSpacing: pixelSpacing,
      reviewed: vessel.reviewed,
      lumenWall: vessel.lumenWall,
      vesselWall: vessel.vesselWall,
      vesselWallMesh: switchMeshFormatToDrc(vessel.vesselWallMesh),
      statistics: vessel.statistics,
      plaqueAreas: vessel.plaqueAreas,
      shape: vessel.shape,
      smpr: vessel.smpr &&
        {
          width: vessel.smpr.width,
          height: vessel.smpr.height,
          length: vessel.smpr.length,
          dataUrl: `${url.content}/${getS3InfoFromURI(vessel.smpr.referenceFile).key}`
        }
    }, _.isNil)
  },

  getCTOArea (areas: Array<Area>) {
    return _.head(_.filter(areas, { type: TOOLS.CTO }))
  }
}
